@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -24,6 +24,10 @@ const DEFAULT_LOCAL_ADDR: (Ipv4Addr, u16) = (Ipv4Addr::UNSPECIFIED, 0);
 
 /// Default amount of time to wait for responses to queries before giving up and returning an error.
 pub const DEFAULT_QUERY_TIMEOUT: Duration = Duration::from_secs(120);
+/// Default idle timeout on the elder connection
+const DEFAULT_IDLE_TIMEOUT: Duration = Duration::from_secs(120);
+/// Default keep alive for elder comms
+const DEFAULT_KEEP_ALIVE: Duration = Duration::from_secs(30);
 /// Default amount of time to wait (to keep the client alive) after sending a command. This allows AE messages to be parsed/resent.
 /// Larger PUT operations may need larger ae wait time
 pub const DEFAULT_AE_WAIT: Duration = Duration::from_secs(0);
@@ -78,8 +82,8 @@ impl ClientConfig {
             Some(path) => read_config_file(path).await.unwrap_or_default(),
         };
 
-        qp2p.idle_timeout = Some(DEFAULT_QUERY_TIMEOUT);
-        qp2p.keep_alive_interval = Some(Duration::from_secs(30));
+        qp2p.idle_timeout = Some(DEFAULT_IDLE_TIMEOUT);
+        qp2p.keep_alive_interval = Some(DEFAULT_KEEP_ALIVE);
 
         let query_timeout = query_timeout.unwrap_or(DEFAULT_QUERY_TIMEOUT);
         let standard_wait = standard_wait.unwrap_or(DEFAULT_AE_WAIT);
@@ -240,8 +244,8 @@ mod tests {
             root_dir: root_dir.clone(),
             genesis_key,
             qp2p: QuicP2pConfig {
-                idle_timeout: Some(Duration::from_secs(120)),
-                keep_alive_interval: Some(Duration::from_secs(30)),
+                idle_timeout: Some(DEFAULT_IDLE_TIMEOUT),
+                keep_alive_interval: Some(DEFAULT_KEEP_ALIVE),
                 ..Default::default()
             },
             query_timeout: expected_query_timeout,
