@@ -17,6 +17,16 @@ mod service_msgs;
 mod update_section;
 
 use crate::dbs::Error as DbError;
+use crate::messaging::{
+    data::{ServiceMsg, StorageLevel},
+    signature_aggregator::Error as AggregatorError,
+    system::{
+        JoinRequest, JoinResponse, NodeCmd, NodeEvent, NodeQuery, SectionAuth as SystemSectionAuth,
+        SystemMsg,
+    },
+    AuthorityProof, DstLocation, MessageId, MessageType, MsgKind, NodeMsgAuthority, SectionAuth,
+    ServiceAuth, WireMsg,
+};
 use crate::node::{
     api::command::Command,
     core::{Core, DkgSessionInfo},
@@ -26,19 +36,6 @@ use crate::node::{
 };
 use crate::peer::{Peer, UnnamedPeer};
 use crate::types::{log_markers::LogMarker, PublicKey, Signature};
-use crate::{
-    messaging::{
-        data::{ServiceMsg, StorageLevel},
-        signature_aggregator::Error as AggregatorError,
-        system::{
-            JoinRequest, JoinResponse, NodeCmd, NodeQuery, SectionAuth as SystemSectionAuth,
-            SystemMsg,
-        },
-        AuthorityProof, DstLocation, MessageId, MessageType, MsgKind, NodeMsgAuthority,
-        SectionAuth, ServiceAuth, WireMsg,
-    },
-    types::ReplicatedData,
-};
 
 use bls::PublicKey as BlsPublicKey;
 use bytes::Bytes;
@@ -651,61 +648,70 @@ impl Core {
                 Ok(vec![])
             }
             SystemMsg::NodeCmd(NodeCmd::ReceiveMetadata { metadata }) => {
-                info!("Processing received DataExchange packet: {:?}", msg_id);
+                info!("Processing received MetadataExchange packet: {:?}", msg_id);
                 self.set_adult_levels(metadata).await;
                 Ok(vec![])
             }
-            SystemMsg::NodeCmd(NodeCmd::StoreData { data, .. }) => {
-                info!("Processing chunk write with MessageId: {:?}", msg_id);
-                // There is no point in verifying a sig from a sender A or B here.
-
-                // This may return a DatabaseFull error... but we should have reported storage increase
-                // well before this
-                match self.data_storage.store(&data).await {
-                    Ok(level_report) => {
-                        info!("Storage level report: {:?}", level_report);
-                        return Ok(self.record_if_any(level_report).await);
-                    }
-                    Err(error) => {
-                        error!("Error storing data: {:?}", error);
-                        let mut commands = vec![];
-
-                        // if the error was Disk Full
-                        if matches!(error, DbError::NotEnoughSpace) {
-                            warn!("Db errored as full. Informing elders");
-                            let level = StorageLevel::from(10)?;
-                            commands.extend(self.record_if_any(Some(level)).await);
+            SystemMsg::NodeEvent(NodeEvent::CouldNotStoreData {
+                node_id,
+                data,
+                full,
+            }) => {
+                info!(
+                    "Processing CouldNotStoreData event with MessageId: {:?}",
+                    msg_id
+                );
+                return if self.is_elder().await {
+                    if full {
+                        let changed = self
+                            .set_storage_level(&node_id, StorageLevel::from(StorageLevel::MAX)?)
+                            .await;
+                        if changed {
+                            // ..then we accept a new node in place of the full node
+                            *self.joins_allowed.write().await = true;
                         }
-
-                        let msg = SystemMsg::NodeCmd(NodeCmd::RepublishData(data));
-                        commands.push(self.send_message_to_our_elders(msg).await?);
-
-                        Ok(commands)
                     }
-                }
+                    self.replicate_data(data).await
+                } else {
+                    error!("Received unexpected message while Adult");
+                    Ok(vec![])
+                };
             }
             SystemMsg::NodeCmd(NodeCmd::ReplicateData(data)) => {
                 info!("Processing replicate data cmd with MessageId: {:?}", msg_id);
-
                 return if self.is_elder().await {
-                    self.republish_data(data).await
+                    error!("Received unexpected message while Elder");
+                    Ok(vec![])
                 } else {
                     // We are an adult here, so just store away!
+                    // This may return a DatabaseFull error... but we should have reported storage increase
+                    // well before this
+                    match self.data_storage.store(&data).await {
+                        Ok(level_report) => {
+                            info!("Storage level report: {:?}", level_report);
+                            return Ok(self.record_if_any(level_report).await);
+                        }
+                        Err(error) => {
+                            let full = match error {
+                                //DbError::Io(_) | DbError::Sled(_) => false, // potential transient errors
+                                DbError::NotEnoughSpace => true, // db full
+                                _ => return Ok(vec![]), // the rest seem to be non-problematic errors.. (?)
+                            };
 
-                    // TODO: should this be a cmd returned for threading?
-                    let level_report = self.data_storage.store_for_replication(&data).await?;
-                    Ok(self.record_if_any(level_report).await)
+                            error!("Error storing data: {:?}", error);
+
+                            let node_id = PublicKey::from(self.node.read().await.keypair.public);
+                            let msg = SystemMsg::NodeEvent(NodeEvent::CouldNotStoreData {
+                                node_id,
+                                data,
+                                full,
+                            });
+
+                            Ok(vec![self.send_message_to_our_elders(msg).await?])
+                        }
+                    }
                 };
             }
-            SystemMsg::NodeCmd(NodeCmd::RepublishData(data)) => {
-                info!(
-                    "Republishing data {:?} with MessageId {:?}",
-                    data.name(),
-                    msg_id
-                );
-
-                return self.republish_data(data).await;
-            }
             SystemMsg::NodeCmd(node_cmd) => {
                 self.send_event(Event::MessageReceived {
                     msg_id,
@@ -891,27 +897,6 @@ impl Core {
         cmds
     }
 
-    // Locate ideal holders for this data, line up wiremsgs for those to instruct them to store the data
-    async fn republish_data(&self, data: ReplicatedData) -> Result<Vec<Command>> {
-        if self.is_elder().await {
-            let target_holders = self.get_adults_who_should_store_data(data.name()).await;
-            info!(
-                "Republishing data {:?} to holders {:?}",
-                data.name(),
-                &target_holders,
-            );
-
-            let msg = SystemMsg::NodeCmd(NodeCmd::ReplicateData(data));
-            let aggregation = false;
-
-            self.send_node_msg_to_targets(msg, target_holders, aggregation)
-                .await
-        } else {
-            error!("Received unexpected message while Adult");
-            Ok(vec![])
-        }
-    }
-
     /// Takes a message and forms commands to send to specified targets
     pub(super) async fn send_node_msg_to_targets(
         &self,
